Missing Comparisons
===================

We currently don't have any comparative Pyramid-vs-CMF information
about the following concepts within this tutorial:

- Templates

- Forms

- Membership

- Discussions

- Syndication

- Dublincore

Please ask on the `Pylons-devel maillist
<http://groups.google.com/group/pylons-devel>`_ or on the `#pylons IRC
channel <http://irc.freenode.net#pylons>`_ about these topics.

